@@ -1,18 +1,18 @@
 """Define an object to work directly with the API."""
+from __future__ import annotations
+
 import asyncio
-import logging
 from time import time
-from typing import Dict, Optional
+from typing import Any, cast
 from uuid import uuid4
 
 from aiohttp import ClientSession
 from aiohttp.client_exceptions import ClientError
 
+from .const import LOGGER
 from .errors import InvalidAuthError, RequestError
 from .tile import Tile
 
-_LOGGER = logging.getLogger(__name__)
-
 API_URL_SCAFFOLD = "https://production.tile-api.com/api/v1"
 
 DEFAULT_API_VERSION = "1.0"
@@ -23,7 +23,7 @@ DEFAULT_TIMEOUT = 10
 DEFAULT_USER_AGENT = "Tile/4774 CFNetwork/1312 Darwin/21.0.0"
 
 
-class API:  # pylint: disable=too-many-instance-attributes
+class API:
     """Define the API management object."""
 
     def __init__(
@@ -32,21 +32,44 @@ class API:  # pylint: disable=too-many-instance-attributes
         password: str,
         session: ClientSession,
         *,
-        client_uuid: Optional[str] = None,
+        client_uuid: str | None = None,
         locale: str = DEFAULT_LOCALE,
     ) -> None:
-        """Initialize."""
+        """Initialize.
+
+        Args:
+            email: An email address for a Tile account.
+            password: The account password.
+            session: An optional aiohttp ClientSession.
+            client_uuid: An optional UUID to identify this API object.
+            locale: An optional locale.
+        """
         self._client_established: bool = False
         self._email: str = email
         self._locale: str = locale
         self._password: str = password
         self._session: ClientSession = session
-        self._session_expiry: Optional[int] = None
-        self.client_uuid: str = str(uuid4()) if not client_uuid else client_uuid
-        self.user_uuid: Optional[str] = None
+        self._session_expiry: int | None = None
+        self.client_uuid: str = client_uuid if client_uuid else str(uuid4())
+        self.user_uuid: str | None = None
 
-    async def _async_request(self, method: str, endpoint: str, **kwargs) -> dict:
-        """Make a request against Tile."""
+    async def _async_request(
+        self, method: str, endpoint: str, **kwargs: dict[str, Any]
+    ) -> dict[str, Any]:
+        """Make an API request.
+
+        Args:
+            method: An HTTP method.
+            endpoint: A relative API endpoint.
+            **kwargs: Additional kwargs to send with the request.
+
+        Returns:
+            An API response payload.
+
+        Raises:
+            InvalidAuthError: Raised upon invalid credentials.
+            RequestError: Raised upon an underlying HTTP error.
+        """
         if self._session_expiry and self._session_expiry <= int(time() * 1000):
             await self.async_init()
 
@@ -60,7 +83,6 @@ class API:  # pylint: disable=too-many-instance-attributes
         async with self._session.request(
             method, f"{API_URL_SCAFFOLD}/{endpoint}", **kwargs
         ) as resp:
-            print(resp.cookies)
             try:
                 resp.raise_for_status()
                 data = await resp.json()
@@ -71,12 +93,16 @@ class API:  # pylint: disable=too-many-instance-attributes
                     f"Error requesting data from {endpoint}: {err}"
                 ) from err
 
-        _LOGGER.debug("Data received from /%s: %s", endpoint, data)
+        LOGGER.debug("Data received from /%s: %s", endpoint, data)
 
-        return data
+        return cast(dict[str, Any], data)
 
-    async def async_get_tiles(self) -> Dict[str, Tile]:
-        """Get all active Tiles from the user's account."""
+    async def async_get_tiles(self) -> dict[str, Tile]:
+        """Get all active Tiles from the user's account.
+
+        Returns:
+            A dictionary of Tile UUIDs to Tile objects.
+        """
         states = await self._async_request("get", "tiles/tile_states")
 
         details_tasks = {
@@ -125,10 +151,21 @@ async def async_login(
     password: str,
     session: ClientSession,
     *,
-    client_uuid: Optional[str] = None,
+    client_uuid: str | None = None,
     locale: str = DEFAULT_LOCALE,
 ) -> API:
-    """Return an authenticated client."""
-    api = API(email, password, session, client_uuid=client_uuid, locale=locale)
+    """Return an authenticated client.
+
+    Args:
+        email: An email address for a Tile account.
+        password: The account password.
+        session: An optional aiohttp ClientSession.
+        client_uuid: An optional UUID to identify this API object.
+        locale: An optional locale.
+
+    Returns:
+        An authenticated API object.
+    """
+    api: API = API(email, password, session, client_uuid=client_uuid, locale=locale)
     await api.async_init()
     return api
